
=========================
PrismStudio User Guide
=========================


.. toctree::
  :maxdepth: 1
  :hidden:

  korean
  english

.. _badges-buttons:

.. grid::

    .. grid-item-card::

        .. image:: ../_static/english-language-dark.png
          :alt: Usert Guide English
          :class: only-dark main-background

        .. image:: ../_static/english-language-white.png
          :alt: Usert Guide English
          :class: only-light main-background

        **English Version**

        .. button-link:: english.html
            :ref-type: ref
            :color: muted
            :shadow:

            English Version


    .. grid-item-card::

        .. image:: ../_static/korean-language-dark.png
          :alt: User Guide
          :class: only-dark main-background

        .. image:: ../_static/korean-language-white.png
          :alt: User Guide
          :class: only-light main-background

        **Korean Version**

        .. button-link:: korean.html
            :ref-type: ref
            :color: muted
            :shadow:

            Korean Version

